==> datasets.load_1.6.0.tar.gz: datasets.load/README.md <==
datasets.load
========================
[![License](http://img.shields.io/badge/license-GPLv3-brightgreen.svg?style=flat)](http://www.gnu.org/licenses/gpl-3.0.html)
[![CRAN Version](http://www.r-pkg.org/badges/version/datasets.load)](https://cran.r-project.org/package=datasets.load)
[![R build status](https://github.com/bquast/datasets.load/workflows/R-CMD-check/badge.svg)](https://github.com/bquast/datasets.load/actions?workflow=R-CMD-check)
[![Coverage status](https://codecov.io/gh/bquast/datasets.load/branch/master/graph/badge.svg)](https://codecov.io/gh/bquast/datasets.load?branch=master)
[![Total RStudio Cloud Downloads](http://cranlogs.r-pkg.org/badges/grand-total/datasets.load?color=brightgreen)](https://cran.r-project.org/package=datasets.load)
[![Monthly RStudio Cloud Downloads](http://cranlogs.r-pkg.org/badges/datasets.load?color=brightgreen)](https://cran.r-project.org/package=datasets.load)

Visual interface for loading datasets in RStudio from all installed (including unloaded) packages.

Demonstration
---------------
![datasets.load GUI demonstration](https://github.com/bquast/R-demo-GIFs/blob/master/datasets.load.gif)


Installation
------------
You can install the latest **stable** version from [CRAN](https://cran.r-project.org/package=datasets.load).

```r
install.packages('datasets.load')
```

The **development** version, to be used **at your peril**, can be installed from [GitHub](https://github.com/bquast/datasets.load) using the `devtools` package.

```r
if (!require('remotes')) install.packages('remotes')
remotes::install_github('bquast/datasets.load')
```

Development
-------------
Development takes place on the GitHub page.

https://github.com/bquast/datasets.load

Bugs can be filed on the issues page on GitHub.

https://github.com/bquast/datasets.load/issues

==> datasets.load_2.0.0.tar.gz: datasets.load/README.md <==
datasets.load
========================
[![License](http://img.shields.io/badge/license-GPLv3-brightgreen.svg?style=flat)](http://www.gnu.org/licenses/gpl-3.0.html)
[![CRAN Version](http://www.r-pkg.org/badges/version/datasets.load)](https://cran.r-project.org/package=datasets.load)
[![R build status](https://github.com/bquast/datasets.load/workflows/R-CMD-check/badge.svg)](https://github.com/bquast/datasets.load/actions?workflow=R-CMD-check)
[![Coverage status](https://codecov.io/gh/bquast/datasets.load/branch/master/graph/badge.svg)](https://app.codecov.io/gh/bquast/datasets.load?branch=master)
[![Total RStudio Cloud Downloads](http://cranlogs.r-pkg.org/badges/grand-total/datasets.load?color=brightgreen)](https://cran.r-project.org/package=datasets.load)
[![Monthly RStudio Cloud Downloads](http://cranlogs.r-pkg.org/badges/datasets.load?color=brightgreen)](https://cran.r-project.org/package=datasets.load)

Visual interface for loading datasets in RStudio from all installed (including unloaded) packages.

Demonstration
---------------
![datasets.load GUI demonstration](https://github.com/bquast/R-demo-GIFs/blob/master/datasets.load.gif)


Installation
------------
You can install the latest **stable** version from [CRAN](https://cran.r-project.org/package=datasets.load).

```r
install.packages('datasets.load')
```

The **development** version, to be used **at your peril**, can be installed from [GitHub](https://github.com/bquast/datasets.load) using the `devtools` package.

```r
if (!require('remotes')) install.packages('remotes')
remotes::install_github('bquast/datasets.load')
```

Development
-------------
Development takes place on the GitHub page.

https://github.com/bquast/datasets.load

Bugs can be filed on the issues page on GitHub.

https://github.com/bquast/datasets.load/issues
